==> haskell-hspec-attoparsec-0.1.0.2-260-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-attoparsec
version:              0.1.0.2
visibility:           public
id:                   hspec-attoparsec-0.1.0.2-IFL922o1PhNKk4QcBZL5E3
key:                  hspec-attoparsec-0.1.0.2-IFL922o1PhNKk4QcBZL5E3
license:              BSD-3-Clause
copyright:            2014-2015 Alp Mestanogullari
maintainer:           alpmestan@gmail.com
author:               Alp Mestanogullari
homepage:             http://github.com/alpmestan/hspec-attoparsec
synopsis:
    Utility functions for testing your attoparsec parsers with hspec

description:
    This package provides some helper functions for testing attoparsec parsers with hspec.

    See the documentation in @Test.Hspec.Attoparsec@ for examples, or this package'\''s own test suite.

category:             Testing, Parsing
abi:                  0e07d70cb4e2d19e34fa3b15a4b0df43
exposed:              True
exposed-modules:      Test.Hspec.Attoparsec Test.Hspec.Attoparsec.Source
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-attoparsec-0.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-attoparsec-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-attoparsec-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-attoparsec
hs-libraries:         HShspec-attoparsec-0.1.0.2-IFL922o1PhNKk4QcBZL5E3
depends:
    attoparsec-0.14.4-IxPlyKeM7RE2Q1eOkxwOEV base-4.17.2.1
    bytestring-0.11.5.3 hspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hspec-attoparsec/html/hspec-attoparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-attoparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-attoparsec-0.1.0.2-261-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-attoparsec
version:              0.1.0.2
visibility:           public
id:                   hspec-attoparsec-0.1.0.2-8FEKxjnPfsBA9nIOXyLJCo
key:                  hspec-attoparsec-0.1.0.2-8FEKxjnPfsBA9nIOXyLJCo
license:              BSD-3-Clause
copyright:            2014-2015 Alp Mestanogullari
maintainer:           alpmestan@gmail.com
author:               Alp Mestanogullari
homepage:             http://github.com/alpmestan/hspec-attoparsec
synopsis:
    Utility functions for testing your attoparsec parsers with hspec

description:
    This package provides some helper functions for testing attoparsec parsers with hspec.

    See the documentation in @Test.Hspec.Attoparsec@ for examples, or this package'\''s own test suite.

category:             Testing, Parsing
abi:                  68ab70e851aa506e4ec3eff7ad154e54
exposed:              True
exposed-modules:      Test.Hspec.Attoparsec Test.Hspec.Attoparsec.Source
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-attoparsec-0.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-attoparsec-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-attoparsec-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-attoparsec
hs-libraries:         HShspec-attoparsec-0.1.0.2-8FEKxjnPfsBA9nIOXyLJCo
depends:
    attoparsec-0.14.4-6kRuW0kw4gG3rg1QrsDffs base-4.17.2.1
    bytestring-0.11.5.3 hspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hspec-attoparsec/html/hspec-attoparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-attoparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
